==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/modules/dhcpd/dhcpd.m <==
extern const char **_dictionary_dhcpd;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_dhcpd;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_dhcpd("dhcpd",_dictionary_dhcpd,58,0);\
	void dummy_dict_dhcpd(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_dhcpd[id]
	#define MSG_B(id,m,n)	_dictionary_dhcpd[id]
	#define MSG_R(id)	_dictionary_dhcpd[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_dhcpd,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_dhcpd,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_dhcpd,id)
#endif
#define M_DHCP	0
#define F_ROUTERS	1
#define F_DNS	2
#define F_DOMAIN	3
#define F_SUBNETMASK	4
#define F_TIMEOFFSET	5
#define F_LOGSERVERS	6
#define F_LPRSERVERS	7
#define F_TIMESERVERS	8
#define F_COOKIESERVERS	9
#define F_DHHOSTNAME	10
#define F_WINS	11
#define E_DHPARSE	12
#define E_IVLDHOSTIP	13
#define E_IVLDNETIP	14
#define F_NETWORK	15
#define F_DYNBOOTP	16
#define F_STARTIP	17
#define F_STOPIP	18
#define F_DEFLEASETIME	19
#define F_MAXLEASETIME	20
#define T_ONESUB	21
#define I_ONESUB	22
#define F_IDENT	23
#define T_DHCPDEF	24
#define I_DHCPDEF	25
#define M_EDIT	26
#define M_DEFOPT	27
#define T_SUBNETS	28
#define H_SUBNETS	29
#define T_BOOTPHOST	30
#define B_ADDSUBNET	31
#define B_ADDBOOTP	32
#define T_DHCPCONF	33
#define I_DHCPCONF	34
#define F_NETMASK	35
#define E_NOMATCH	36
#define M_UPDATEDNS	37
#define M_UPDATE	38
#define H_SHOWALLOC	39
#define T_SHOWALLOC	40
#define M_VIEWLEASES	41
#define M_VIEW	42
#define E_USAGE	43
#define E_NODNSSUPPORT	44
#define N_UPDATED	45
#define N_UPTODATE	46
#define T_BASIC	47
#define T_SERVERS	48
#define T_OTHERS	49
#define F_DEFDNSDOM	50
#define E_DNSDOM	51
#define T_DNS	52
#define F_UPDDNS	53
#define I_UPDDNS	54
#define E_CANUPDDNS	55
#define F_NETBIOSNODETYPE	56
#define T_RANGES	57

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/modules/dhcpd/dhcpd.m <==
extern const char **_dictionary_dhcpd;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_dhcpd;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_dhcpd("dhcpd",_dictionary_dhcpd,66,0);\
	void dummy_dict_dhcpd(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_dhcpd[id]
	#define MSG_B(id,m,n)	_dictionary_dhcpd[id]
	#define MSG_R(id)	_dictionary_dhcpd[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_dhcpd,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_dhcpd,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_dhcpd,id)
#endif
#define M_DHCP	0
#define F_ROUTERS	1
#define F_DNS	2
#define F_DOMAIN	3
#define F_SUBNETMASK	4
#define F_TIMEOFFSET	5
#define F_LOGSERVERS	6
#define F_LPRSERVERS	7
#define F_TIMESERVERS	8
#define F_COOKIESERVERS	9
#define F_DHHOSTNAME	10
#define F_WINS	11
#define E_DHPARSE	12
#define E_IVLDHOSTIP	13
#define E_IVLDNETIP	14
#define F_NETWORK	15
#define F_DYNBOOTP	16
#define F_STARTIP	17
#define F_STOPIP	18
#define F_DEFLEASETIME	19
#define F_MAXLEASETIME	20
#define T_ONESUB	21
#define I_ONESUB	22
#define F_IDENT	23
#define T_DHCPDEF	24
#define I_DHCPDEF	25
#define M_EDIT	26
#define M_DEFOPT	27
#define T_SUBNETS	28
#define H_SUBNETS	29
#define T_BOOTPHOST	30
#define B_ADDSUBNET	31
#define B_ADDBOOTP	32
#define T_DHCPCONF	33
#define I_DHCPCONF	34
#define F_NETMASK	35
#define E_NOMATCH	36
#define M_UPDATEDNS	37
#define M_UPDATE	38
#define H_SHOWALLOC	39
#define T_SHOWALLOC	40
#define M_VIEWLEASES	41
#define M_VIEW	42
#define E_USAGE	43
#define E_NODNSSUPPORT	44
#define N_UPDATED	45
#define N_UPTODATE	46
#define T_BASIC	47
#define T_SERVERS	48
#define T_OTHERS	49
#define F_DEFDNSDOM	50
#define E_DNSDOM	51
#define T_DNS	52
#define F_UPDDNS	53
#define I_UPDDNS	54
#define E_CANUPDDNS	55
#define F_NETBIOSNODETYPE	56
#define T_RANGES	57
#define F_NISDOMAIN	58
#define F_NISSERVER	59
#define T_NIS	60
#define T_METBIOS	61
#define I_VALIDNAMEONLY	62
#define I_CREATELEASE	63
#define E_IVLDNETWORKIP	64
#define E_IVLDNETHOSTIP	65
